"use strict";
this.name = "StationDockControl_HackChip";
this.author = "phkb";
this.copyright = "2015 phkb";
this.description = "Script to control the use of the SDC Hack Chip";
this.license = "CC BY-NC-SA 3.0";

this._chipInstalled = false;
this._installTimer = null;
this._installCount = 0;
this._installStation = null;
this._confiscate = false;
this._debug = false;

//-------------------------------------------------------------------------------------------------------------
this.startUpComplete = function () {
	if (missionVariables.StationDockControl_HackChipCount) this._installCount = missionVariables.StationDockControl_HackChipCount;
	this.$initInterface(player.ship.dockedStation);

	// remove the hack chip from any maintenance emails
	var w = worldScripts.GalCopAdminServices;
	if (w) w._maint_ignore_equip.push("EQ_SDC_HACK_CHIP");
}

//-------------------------------------------------------------------------------------------------------------
this.shipDockedWithStation = function (station) {
	if (this._confiscate === true && station.allegiance === "galcop") {
		player.ship.removeEquipment("EQ_SDC_HACK_CHIP");
		// send an email
		var w = worldScripts.EmailSystem;
		if (w) {
			w.$createEmail({
				sender: "GalCop Security",
				subject: "Computer systems security breach",
				date: global.clock.seconds,
				message: "Commander " + player.name + ",\n\nGalCop network specialists had detected the use of an illegal security device while your ship was previously docked in this system. " +
					" This device has now been appropriated." +
					"\n\nGalCop takes the security of it's network seriously and it would be prudent to do the same yourself.\n\nGood day, Commander.\n\n" +
					expandDescription("%N [nom]") + "\nGalCop Security Officer"
			});
		}
	}
	this.$initInterface(station);
}

//-------------------------------------------------------------------------------------------------------------
this.shipExitedWitchspace = function () {
	// reset the install counter
	this._installCount = 0;
	this._confiscate = false;
}

//-------------------------------------------------------------------------------------------------------------
this.playerBoughtEquipment = function (equipmentKey) {
	if (equipmentKey === "EQ_SDC_HACK_CHIP") {
		this.$initInterface(player.ship.dockedStation);
	}
}

//-------------------------------------------------------------------------------------------------------------
this.playerWillSaveGame = function () {
	missionVariables.StationDockControl_HackChipCount = this._installCount;
	/* Note: We're not storing the state of the hack chip. This means, if the player installs the hack chip and then saves the game, when they
	restore the game the chip won't be installed. However, the number of times they have installed the chip is captured.
	This is probably the easier way of limiting any save game abuse, without having to store the state of the timer.
	*/
}

//-------------------------------------------------------------------------------------------------------------
this.shipLaunchedFromStation = function (station) {
	if (this._chipInstalled === true) {
		// there's a couple of options here, based on how the hack chip would actually be installed
		// if the hack ship is installed inside your ship, then launching would simplky uninstalled it
		// if the hack chip is installed at a computer port outside your ship, then launching would leave it behind
		// for the moment i'm going with the second option
		this._chipInstalled = false;
		player.ship.removeEquipment("EQ_SDC_HACK_CHIP");
		this._installTimer.stop();
	}
}

//-------------------------------------------------------------------------------------------------------------
this.$initInterface = function $initInterface(station) {
	if (player.ship.equipmentStatus("EQ_SDC_HACK_CHIP") === "EQUIPMENT_OK" && (station.allegiance === "galcop" || this._debug === true)) {
		station.setInterface(this.name, {
			title: "Install SDC hack chip",
			category: "Ship Systems",
			summary: "Installs the SDC hack chip into the GalCop ship systems interface terminal.",
			callback: this.$installHackChip.bind(this)
		});
	} else {
		this.$removeInterface(station);
	}
}

//-------------------------------------------------------------------------------------------------------------
this.$removeInterface = function $removeInterface(station) {
	station.setInterface(this.name, null);
}

//-------------------------------------------------------------------------------------------------------------
this.$installHackChip = function $installHackChip() {
	this._chipInstalled = true;
	// switch the interface display
	player.ship.dockedStation.setInterface(this.name, {
		title: "Remove SDC hack chip",
		category: "Ship Systems",
		summary: "Removes the SDC hack chip from the GalCop ship systems interface terminal.",
		callback: this.$removeHackChip.bind(this)
	});
	// start a timer
	// calc how long the player has
	var secs = (25 - (this._installCount * 10)) - system.info.techlevel;
	if (secs < 5) secs = 5;

	this._installCount += 1;
	this._installStation = player.ship.dockedStation;

	mission.runScreen({
		screenID: "oolite-sdc-hackchip-summary",
		title: "SDC Hack Chip",
		overlay: {
			name: "sdc-unlock.png",
			height: 546
		},
		message: "The SDC Hack Chip has been installed successfully",
		exitScreen: "GUI_SCREEN_INTERFACES"
	});

	if (this._installTimer && this._installTimer.isRunning) this._installTimer.stop();
	this._installTimer = new Timer(this, this.$installTimer, secs, 0);
}

//-------------------------------------------------------------------------------------------------------------
this.$installTimer = function $installTimer() {
	// caught!!
	this._chipInstalled = false;
	this._installTimer = null;
	// remove the hack chip (if we're still docked)
	if (player.alertCondition === 0) {
		player.ship.removeEquipment("EQ_SDC_HACK_CHIP");
		this.$removeInterface(this._installStation);
	}
	// fine the player
	player.ship.setBounty(player.bounty + 30, "illegal activity");
	var fine_amount = 5000;
	if (player.credits > fine_amount) {
		player.credits -= fine_amount;
	} else {
		fine_amount = player.credits;
		player.credits = 0;
	}
	var w = worldScripts.EmailSystem;
	if (player.alertCondition !== 0) {
		// confiscate the chip if the play docks in the same system
		this._confiscate = true;
		this._installStation.commsMessage("GalCop security breach detected! You have been fined and your bounty increased!", player.ship);
		if (w) {
			w.$createEmail({
				sender: "GalCop Security",
				subject: "Computer systems security breach",
				date: global.clock.seconds,
				message: "Commander " + player.name + ",\n\nGalCop network specialists detected a security breach and traced the packet data to an " +
					"illegal device attached to a computer terminal in your vessel while you docked in " + system.info.name + ". You have been given a bounty and fined " + formatCredits(fine_amount, true, true) +
					".\n\nGalCop takes the security of it's network seriously and it would be prudent to do the same yourself.\n\nGood day, Commander.\n\n" +
					expandDescription("%N [nom]") + "\nGalCop Security Officer"
			});
		}
	} else {
		player.consoleMessage("GalCop security breach detected! You have been fined, your bounty has been increased, and the device confiscated!");
		// send an email, if installed
		if (w) {
			w.$createEmail({
				sender: "GalCop Security",
				subject: "Computer systems security breach",
				date: global.clock.seconds,
				message: "Commander " + player.name + ",\n\nGalCop network specialists detected a security breach and traced the packet data to an " +
					"illegal device attached to a computer terminal in your vessel. This device has been appropriated, and you have been given a bounty and fined " + formatCredits(fine_amount, true, true) +
					".\n\nGalCop takes the security of it's network seriously and it would be prudent to do the same yourself.\n\nGood day, Commander.\n\n" +
					expandDescription("%N [nom]") + "\nGalCop Security Officer"
			});
		}
	}

}

//-------------------------------------------------------------------------------------------------------------
this.$removeHackChip = function $removeHackChip() {
	this._installTimer.stop();
	this._chipInstalled = false;
	this.$initInterface(player.ship.dockedStation);
	mission.runScreen({
		screenID: "oolite-sdc-hackchip-summary",
		title: "SDC Hack Chip",
		overlay: {
			name: "sdc-lock.png",
			height: 546
		},
		message: "The SDC Hack Chip has been removed successfully",
		exitScreen: "GUI_SCREEN_INTERFACES"
	});
}