"use strict";
this.name = "StationDockControl_ShuttleLaunch";
this.author = "phkb";
this.copyright = "2015 phkb";
this.description = "Script to attach to a shuttle after launch to set its target";
this.license = "CC BY-NC-SA 3.0";

/*
	This script is designed to force a particular in-system destination on a shuttle.
	Because the priority AI controller takes a few moments to start up, we need to wait for it to be active before we can redirect the shuttle.
	So a timer is used. The timer is a one-shot, but it will be restarted if the controller isn't active.
*/

//-------------------------------------------------------------------------------------------------------------
this.$initialise = function $initialise() {
	// run a timer so the ai controller has a chance to startup besofe we try and set the destination
	this.ship.script._retryCounter = 0;
	//log(this.name, "setting timer for shuttle destination - " + this.ship.displayName);
	this.ship.script._setDest = new Timer(this, this.ship.script.$setDestination, 2, 0);
}

//-------------------------------------------------------------------------------------------------------------
this.$setDestination = function $setDestination() {
	// do we have a ai controller yet?
	if (!this.ship.AIScript.oolite_priorityai) {
		// start counting after ship is in flight
		if (this.ship.status !== "STATUS_IN_FLIGHT") {
			this.ship.script._retryCounter += 1;
		}
		// give up after ten tries
		if (this.ship.script._retryCounter === 10) {
			//log(this.name, "giving up trying to set shuttle destination for " + this.ship.displayName);
			return;
		}

		// otherwise, reset the timer and try again later
		delete this.ship.script._setDest;

		//log(this.name, "resetting timer for shuttle destination - " + this.ship.displayName);
		this.ship.script._setDest = new Timer(this, this.ship.script.$setDestination, 2, 0);
		return;
	}

	var w = worldScripts.StationDockControl;
	var debug = w._debug;
	var l_debug = w._logLaunchType;

	var items = this._dest.split("|");
	if (items[0] !== "Planet") {
		var stnLoc = w.$getStationFromName(items[0], parseInt(items[1]));
		// check if we got an actual ship location returned
		if (stnLoc) {
			this.ship.AIScript.oolite_priorityai.setParameter("oolite_selectedPlanet", null);
			this.ship.AIScript.oolite_priorityai.setParameter("oolite_selectedStation", stnLoc);
			if (debug && l_debug >= 2) log(this.name, "Setting " + this.ship.displayName + " destination location to " + stnLoc);
		}
	} else {
		this.ship.AIScript.oolite_priorityai.setParameter("oolite_selectedStation", null);
		this.ship.AIScript.oolite_priorityai.setParameter("oolite_selectedPlanet", system.mainPlanet);
		if (debug && l_debug >= 2) log(this.name, "Setting " + this.ship.displayName + " destination location to main planet");
	}
	this.ship.AIScript.oolite_priorityai.reconsiderNow();

	delete this.ship.script._setDest;
}

//-------------------------------------------------------------------------------------------------------------
this.npc_shipDied = function npc_shipDied(whom, why) {
	if (this.ship.script.$sdc_hold_shipDied) this.ship.script.$sdc_hold_shipDied(whom, why);
	if (this.ship.script._setDest && this.ship.script._setDest.isRunning) this.ship.script._setDest.stop();
}

//-------------------------------------------------------------------------------------------------------------
this.npc_shipWillEnterWormhole = function npc_shipWillEnterWormhole() {
	if (this.ship.script.$sdc_hold_shipWillEnterWormhole) this.ship.script.$sdc_hold_shipWillEnterWormhole();
	if (this.ship.script._setDest && this.ship.script._setDest.isRunning) this.ship.script._setDest.stop();
}